var class_ogre_1_1_light =
[
    [ "MovableObjectArray", "class_ogre_1_1_light.html#afb58624fb567bb790c55d8a716b472da", null ],
    [ "LightTypes", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbc", [
      [ "LT_DIRECTIONAL", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca4c5582d28848ce40c2b652488494b4a3", null ],
      [ "LT_POINT", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca0d59bfdcfeb338dbfe06e2e2999e752f", null ],
      [ "LT_SPOTLIGHT", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca8fc40a1ccfb026944417ef92b7ddaefe", null ],
      [ "LT_VPL", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca6b85e19aa8243a75424e990d0c22e596", null ],
      [ "MAX_FORWARD_PLUS_LIGHTS", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca82096faf2c3e88def5977c8520a09794", null ],
      [ "LT_AREA_APPROX", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbcaf7bed0743d1dfef2117f8c21dd51e91e", null ],
      [ "LT_AREA_LTC", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca28725f65eb27dedd10c97848ca3188e2", null ],
      [ "NUM_LIGHT_TYPES", "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca90fd73505abfc3ebfa47c8571ca55b18", null ]
    ] ],
    [ "Reason", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7d", [
      [ "Unknown", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82", null ],
      [ "FromStorageToSysRam", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27", null ],
      [ "FromSysRamToStorage", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b", null ],
      [ "GainedResidency", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1", null ],
      [ "LostResidency", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da61729c4ae25807d6132d5bc46580ff3d", null ],
      [ "PoolTextureSlotChanged", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0", null ],
      [ "ResidentToSysRamSync", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da218a4243be85ec9c989b777119d5ff47", null ],
      [ "MetadataCacheOutOfDate", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604", null ],
      [ "ExceptionThrown", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26", null ],
      [ "FsaaSettingAlteredByApi", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7", null ],
      [ "ReadyForRendering", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dad4d9c6e3b7755f38d8d5f003be100257", null ],
      [ "Deleted", "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e", null ]
    ] ],
    [ "Light", "class_ogre_1_1_light.html#a2e562e3231d1ebdbebb009b5d4bc9af4", null ],
    [ "~Light", "class_ogre_1_1_light.html#afbfeabb7d5503e571528fc0d365dc80a", null ],
    [ "_calcTempSquareDist", "class_ogre_1_1_light.html#a6b0962ead2b2a699af0d2b564450e5ae", null ],
    [ "_deriveShadowFarClipDistance", "class_ogre_1_1_light.html#a97143cbcc65f87597c491e566d793c32", null ],
    [ "_deriveShadowNearClipDistance", "class_ogre_1_1_light.html#a0a7c23a753bf2c7b1ded3b6b874a82a5", null ],
    [ "_getLightList", "class_ogre_1_1_light.html#a862e7d3af40ee31de2f95a626207f96d", null ],
    [ "_getManager", "class_ogre_1_1_light.html#a55237a2e03c449e5c3c62858e61d5494", null ],
    [ "_getObjectData", "class_ogre_1_1_light.html#ab90b269de93324996df439355dd69dd2", null ],
    [ "_getOwnShadowFarDistance", "class_ogre_1_1_light.html#a83464478d3db0b92d4d81071ba015e01", null ],
    [ "_getParentNodeFullTransform", "class_ogre_1_1_light.html#a7241fd29a548973d1d2fa56bcc9f13a4", null ],
    [ "_notifyAttached", "class_ogre_1_1_light.html#a4c29a048d9254c17c43a9fa313df0a6b", null ],
    [ "_notifyManager", "class_ogre_1_1_light.html#a865cb46cc09cbb8bd560abeca1d0d31e", null ],
    [ "_notifyParentNodeMemoryChanged", "class_ogre_1_1_light.html#ae47c1fe914431bbbd47d5d2a3ba258d0", null ],
    [ "_notifyStaticDirty", "class_ogre_1_1_light.html#ab3fe0289fbcabb17897c53445fa29339", null ],
    [ "_releaseManualHardwareResources", "class_ogre_1_1_light.html#a57123ae4fec1b472f25270c1dd6abe59", null ],
    [ "_restoreManualHardwareResources", "class_ogre_1_1_light.html#abd5561a07f78291e327351fe83e64a9b", null ],
    [ "_setLightProfileIdx", "class_ogre_1_1_light.html#a2c43bfbf959d7b0c0680c79ad3469bfb", null ],
    [ "_updateCustomGpuParameter", "class_ogre_1_1_light.html#af333112ff9478bf29693eb59a9caf172", null ],
    [ "_updateRenderQueue", "class_ogre_1_1_light.html#a5a38124467ef557f7f93487407caf069", null ],
    [ "addQueryFlags", "class_ogre_1_1_light.html#a98fe88f82f86eafa19308074495db809", null ],
    [ "addVisibilityFlags", "class_ogre_1_1_light.html#a6b823b52684730302908ecfd1a8e6d54", null ],
    [ "buildLightList", "class_ogre_1_1_light.html#ac4305df204604a027ca27ef77efff295", null ],
    [ "calculateCameraDistance", "class_ogre_1_1_light.html#a64bd61f33ae8a2d4e824ce7e23308d98", null ],
    [ "calculateCastersBox", "class_ogre_1_1_light.html#ab86b755f38ec01b52ed6a512d9d31ef9", null ],
    [ "createAnimableValue", "class_ogre_1_1_light.html#a6e0be3df5d41752c0bedfcf9c89e492b", null ],
    [ "cullFrustum", "class_ogre_1_1_light.html#a7d491859c987cf03cd2b62121e9bfea0", null ],
    [ "cullLights", "class_ogre_1_1_light.html#ac4b8f3f72f7bf7a6bc20dd0677e125c1", null ],
    [ "detachFromParent", "class_ogre_1_1_light.html#a61b39d44e60020d43033a6957895aa5f", null ],
    [ "getAffectParentNode", "class_ogre_1_1_light.html#a0555108e060be64b83dc9cf75e8cf85d", null ],
    [ "getAnimableValueNames", "class_ogre_1_1_light.html#a5f7b365da61eba227c468681e0fb1cde", null ],
    [ "getAs4DVector", "class_ogre_1_1_light.html#a1a93c6cee2acca8aaf140e0430a1edce", null ],
    [ "getAttenuationConstant", "class_ogre_1_1_light.html#a4e4899f7a0b1ecc5e37fe135bb37bec7", null ],
    [ "getAttenuationLinear", "class_ogre_1_1_light.html#aa6978865a8a995606fe9f82eb66002af", null ],
    [ "getAttenuationQuadric", "class_ogre_1_1_light.html#aa839c7ad86c8ea193b2585fab67110a8", null ],
    [ "getAttenuationRange", "class_ogre_1_1_light.html#a9b67c869ff417a54178b4406a8082144", null ],
    [ "getCachedDistanceToCamera", "class_ogre_1_1_light.html#a863bac56e5c968767e811816376d3ce5", null ],
    [ "getCachedDistanceToCameraAsReal", "class_ogre_1_1_light.html#a7c633da32362e05bd24871c7a612fdac", null ],
    [ "getCastShadows", "class_ogre_1_1_light.html#a015c3801632c98bca5dbb5aa3da1aa24", null ],
    [ "getCurrentMeshLod", "class_ogre_1_1_light.html#aff35a0dcf855331bdd0fe72fe0f66824", null ],
    [ "getCustomParameter", "class_ogre_1_1_light.html#ab1014fe5901c78f1b51f00227a6d9f84", null ],
    [ "getCustomParameterNoThrow", "class_ogre_1_1_light.html#ae1752d6520ad9eca130db3cca222e6db", null ],
    [ "getDefaultLightMask", "class_ogre_1_1_light.html#a1a048b8ace0a21cd2ed2c3008941ce3d", null ],
    [ "getDefaultQueryFlags", "class_ogre_1_1_light.html#a01f48775e48b672d7796311f3ffe2930", null ],
    [ "getDefaultVisibilityFlags", "class_ogre_1_1_light.html#a2eb94fea5944cf0d33702a75cfa14a74", null ],
    [ "getDerivedDirection", "class_ogre_1_1_light.html#a2356327c5a908a82f8656996ed43f67a", null ],
    [ "getDerivedDirectionUpdated", "class_ogre_1_1_light.html#a3243b2bb1fed56341351bf97b9a9a492", null ],
    [ "getDerivedRectSize", "class_ogre_1_1_light.html#adbe9a3d02c0984a5a331a160b8a91b10", null ],
    [ "getDiffuseColour", "class_ogre_1_1_light.html#aff98b9ed31a64b4801740ff400ac8e85", null ],
    [ "getDirection", "class_ogre_1_1_light.html#a11d3640138e32ff2d4644dadf5e24c74", null ],
    [ "getDoubleSided", "class_ogre_1_1_light.html#a8d2bda146778c180dc55224bfffe5bed", null ],
    [ "getId", "class_ogre_1_1_light.html#ab152c8f646a835c2f88585ad4fe0413a", null ],
    [ "getLightMask", "class_ogre_1_1_light.html#a54fc365f16014359d23cecf859da5510", null ],
    [ "getLightProfileIdx", "class_ogre_1_1_light.html#a332b43da87b897dee7c36d6f4fdd3a7b", null ],
    [ "getListener", "class_ogre_1_1_light.html#a6944af26e8944b13756ade50cd1092d8", null ],
    [ "getLocalAabb", "class_ogre_1_1_light.html#a30acf249cd312d9eed03a0f3ad618067", null ],
    [ "getLocalRadius", "class_ogre_1_1_light.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3", null ],
    [ "getMovableType", "class_ogre_1_1_light.html#a42fedb6f221a6712b1c21849fb650819", null ],
    [ "getName", "class_ogre_1_1_light.html#abcb1342c56f66f1959ca03441ba826ff", null ],
    [ "getParentNode", "class_ogre_1_1_light.html#a9b4832d473cacad1614494419ffe807f", null ],
    [ "getParentSceneNode", "class_ogre_1_1_light.html#aff8dd8756aba9a9ecb276270e6614c96", null ],
    [ "getPowerScale", "class_ogre_1_1_light.html#aaa6e49d21586b363c4d40a87407be38b", null ],
    [ "getQueryFlags", "class_ogre_1_1_light.html#ad66149b7a6f5ba1cd5c58fbd69f0446a", null ],
    [ "getRectSize", "class_ogre_1_1_light.html#a57d11f3d9ff77b0318d72d639342047f", null ],
    [ "getRenderingDistance", "class_ogre_1_1_light.html#af6788ed3697ab34c561c0afcf39ac8c3", null ],
    [ "getRenderingMinPixelSize", "class_ogre_1_1_light.html#a164483d42186628f7e14833b2df7a7a7", null ],
    [ "getRenderQueueGroup", "class_ogre_1_1_light.html#a4569b91ce5341ab892f74ab4555cac7d", null ],
    [ "getShadowFarClipDistance", "class_ogre_1_1_light.html#af3cd6abc354021078ce103eda3aa2b1a", null ],
    [ "getShadowFarDistance", "class_ogre_1_1_light.html#a63ea738c19ed36e7c0a160585095e9ef", null ],
    [ "getShadowFarDistanceSquared", "class_ogre_1_1_light.html#aaf2c5dfccfad0c80316c9d55ecc07e99", null ],
    [ "getShadowNearClipDistance", "class_ogre_1_1_light.html#a6ffba71e5b797689b61ff0e285449491", null ],
    [ "getShadowRenderingDistance", "class_ogre_1_1_light.html#ab2d58aba9bb1591a393a4a23f4a89142", null ],
    [ "getSkeletonInstance", "class_ogre_1_1_light.html#ae1ec083410e3b53c589239a20fa5dbf0", null ],
    [ "getSpecularColour", "class_ogre_1_1_light.html#a6d84ea02ea0ad4f27fb1c2aeebcbc6e8", null ],
    [ "getSpotlightFalloff", "class_ogre_1_1_light.html#a6372e140e51cab8406adcffefe46a9f5", null ],
    [ "getSpotlightInnerAngle", "class_ogre_1_1_light.html#a55cda420f991dcb9cfc8ccb56fc227b0", null ],
    [ "getSpotlightNearClipDistance", "class_ogre_1_1_light.html#ace79ed42960f5f2860b02bc408fbd767", null ],
    [ "getSpotlightOuterAngle", "class_ogre_1_1_light.html#a20ef8a0dc69223d29971f00a90bf5b35", null ],
    [ "getSpotlightTanHalfAngle", "class_ogre_1_1_light.html#a20900182d64a3aebaddbb34e9717badc", null ],
    [ "getTexture", "class_ogre_1_1_light.html#a68adbcfd66dbe03705a046f383ce587f", null ],
    [ "getType", "class_ogre_1_1_light.html#a8ef572fd5d20b366328cbdb0eb71b4a0", null ],
    [ "getUserObjectBindings", "class_ogre_1_1_light.html#aa6ae8d976be50b007ba1e87732a6397d", null ],
    [ "getUserObjectBindings", "class_ogre_1_1_light.html#a27eb8980ee187b42ea619c582eaebf73", null ],
    [ "getVisibilityFlags", "class_ogre_1_1_light.html#a19bf2951b97744064509c13068143f3d", null ],
    [ "getVisible", "class_ogre_1_1_light.html#af19ca18abcd6ca7bceb2f55a814e1c1b", null ],
    [ "getWorldAabb", "class_ogre_1_1_light.html#a9a72ade896561e23c32cf8659f1640e4", null ],
    [ "getWorldAabbUpdated", "class_ogre_1_1_light.html#aed8ab393d6f46e865a6753be69f96d8b", null ],
    [ "getWorldRadius", "class_ogre_1_1_light.html#a13629b96b4a6b0b34f652234f037d8d9", null ],
    [ "getWorldRadiusUpdated", "class_ogre_1_1_light.html#ad42ba158cac70430c34f8a9eac94b237", null ],
    [ "instanceBatchCullFrustumThreaded", "class_ogre_1_1_light.html#a2d62d2c3d09910210c948fc660468c46", null ],
    [ "isAttached", "class_ogre_1_1_light.html#aef2a2634077942a2939514a6c1114d32", null ],
    [ "isStatic", "class_ogre_1_1_light.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5", null ],
    [ "isVisible", "class_ogre_1_1_light.html#a6c4003f6b67540727844dc33c20714f7", null ],
    [ "notifyTextureChanged", "class_ogre_1_1_light.html#a074b1b671ccfcd0883155be8ab439b17", null ],
    [ "operator delete", "class_ogre_1_1_light.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_light.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_light.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_light.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_light.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_light.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_light.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_light.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_light.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_light.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "operator()", "class_ogre_1_1_light.html#a57e0523432c6e5133ff4fc251111a60e", null ],
    [ "operator()", "class_ogre_1_1_light.html#a0ae22596b5bd2a3faf2958ab3d109d1f", null ],
    [ "queryLights", "class_ogre_1_1_light.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40", null ],
    [ "removeQueryFlags", "class_ogre_1_1_light.html#a6fb94e1627676c7d7517e13944bd0580", null ],
    [ "removeVisibilityFlags", "class_ogre_1_1_light.html#a504e2192036f75007c51e157315e1548", null ],
    [ "resetShadowFarDistance", "class_ogre_1_1_light.html#a0b335a53572a929e720e563b2f45b72c", null ],
    [ "setAffectParentNode", "class_ogre_1_1_light.html#adf841793f9978a635dd0345a6eb7a3e6", null ],
    [ "setAttenuation", "class_ogre_1_1_light.html#a2880f26669477a55cf01919f906bb65d", null ],
    [ "setAttenuationBasedOnRadius", "class_ogre_1_1_light.html#a61ce8158c2eda6a08b884c56bc811783", null ],
    [ "setCastShadows", "class_ogre_1_1_light.html#acbfc4840224e8b6ed6e27849d3341675", null ],
    [ "setCustomParameter", "class_ogre_1_1_light.html#a4e8ebf22380f3c76cd7e901dac362abb", null ],
    [ "setDefaultLightMask", "class_ogre_1_1_light.html#a9a62a4a12787812f012691af0c3493f1", null ],
    [ "setDefaultQueryFlags", "class_ogre_1_1_light.html#ad8db1f22329b2a96f2aed7260d565944", null ],
    [ "setDefaultVisibilityFlags", "class_ogre_1_1_light.html#ac2904cb122ab8c8d5066abefb29dfa96", null ],
    [ "setDiffuseColour", "class_ogre_1_1_light.html#a1cab92f6d67cb87f2ca99d04e897093c", null ],
    [ "setDiffuseColour", "class_ogre_1_1_light.html#adead68de3305bd67d1617352c14da3c3", null ],
    [ "setDirection", "class_ogre_1_1_light.html#a1659111f4eb55f3b3227e87c8bfce8d9", null ],
    [ "setDoubleSided", "class_ogre_1_1_light.html#aa47b4c48c6f868811bd64cee42097ca3", null ],
    [ "setLightMask", "class_ogre_1_1_light.html#a5456ecd630d55c91b2fd1b19969d29f5", null ],
    [ "setListener", "class_ogre_1_1_light.html#ab55eab7ca8e96a3bbb3f69a4095bf067", null ],
    [ "setLocalAabb", "class_ogre_1_1_light.html#ad23fd215ed54a72f90c2b1765dfa8cdb", null ],
    [ "setName", "class_ogre_1_1_light.html#afdf18128b8f4f8be71566ce2d5d5a30a", null ],
    [ "setPowerScale", "class_ogre_1_1_light.html#a8588796e58389701c22fb8e5c62a080e", null ],
    [ "setQueryFlags", "class_ogre_1_1_light.html#a77198e02dd65dd368ea4e6af88a93fda", null ],
    [ "setRectSize", "class_ogre_1_1_light.html#a37f518126915aa920a8b6a70d632d5ee", null ],
    [ "setRenderingDistance", "class_ogre_1_1_light.html#afe1f2a1009e3f14f36e1bcc9b1b9557e", null ],
    [ "setRenderingMinPixelSize", "class_ogre_1_1_light.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7", null ],
    [ "setRenderQueueGroup", "class_ogre_1_1_light.html#adadf14592da40dfe79b40106317a2710", null ],
    [ "setShadowFarClipDistance", "class_ogre_1_1_light.html#aeb90ddb3515b7e3ac936367e40d49d20", null ],
    [ "setShadowFarDistance", "class_ogre_1_1_light.html#ad2db241677e9fd1d48a3c97abeadfe07", null ],
    [ "setShadowNearClipDistance", "class_ogre_1_1_light.html#a91a8c7867631ecda45eb934bfaf0aff1", null ],
    [ "setShadowRenderingDistance", "class_ogre_1_1_light.html#a7cd15e3a5caae8ae786bd752c6b27f26", null ],
    [ "setSpecularColour", "class_ogre_1_1_light.html#a614988755dcedf910f7df90fafe6158e", null ],
    [ "setSpecularColour", "class_ogre_1_1_light.html#a07c50eb182b14e404d34c3a1bcae9664", null ],
    [ "setSpotlightFalloff", "class_ogre_1_1_light.html#aec895d9f784ea062ce69c823737229c5", null ],
    [ "setSpotlightInnerAngle", "class_ogre_1_1_light.html#ad9adeeb164ff515099236e2e8fb0c850", null ],
    [ "setSpotlightNearClipDistance", "class_ogre_1_1_light.html#aead9fea5c5d5869387d88869d0132cad", null ],
    [ "setSpotlightOuterAngle", "class_ogre_1_1_light.html#ad4d52d64dca4df8a930a2401028f73ff", null ],
    [ "setSpotlightRange", "class_ogre_1_1_light.html#a8ef06bd9c2e7113461c50c83c5f09fe9", null ],
    [ "setStatic", "class_ogre_1_1_light.html#a38f8241458458e4f1235eae7d8f850c3", null ],
    [ "setTexture", "class_ogre_1_1_light.html#aec9af1bee1f7349370c7f7367860046e", null ],
    [ "setTextureRaw", "class_ogre_1_1_light.html#aed64949cd01302bef1001588a50c1b4a", null ],
    [ "setType", "class_ogre_1_1_light.html#a6019f7fa89624e35316ba444e519d8f8", null ],
    [ "setVisibilityFlags", "class_ogre_1_1_light.html#a28b12f8d0fd7c9da7fcd1e9806dd8064", null ],
    [ "setVisible", "class_ogre_1_1_light.html#ad563191e86e4d119c62ea9acfc2a90d5", null ],
    [ "shouldStayLoaded", "class_ogre_1_1_light.html#a1427f0b635a4186cd6083a9bab879fa2", null ],
    [ "updateAllBounds", "class_ogre_1_1_light.html#add737d6564593333aeac457a1a2c0269", null ],
    [ "c_DefaultLodMesh", "class_ogre_1_1_light.html#a7c3bff2a6922bbc098c789e9386140e3", null ],
    [ "mGlobalIndex", "class_ogre_1_1_light.html#aee4828c2dee7731058f0b9cd047cf78d", null ],
    [ "mParentIndex", "class_ogre_1_1_light.html#aad9369e62c971d55ca75b7b294c50944", null ],
    [ "mRenderables", "class_ogre_1_1_light.html#ab703ec1f1cf82763b0ac9c4b1e51a17b", null ],
    [ "mTexLightMaskDiffuseMipStart", "class_ogre_1_1_light.html#a8b09bac9505986355e0e18ca31d67c6d", null ],
    [ "mTextureLightMaskIdx", "class_ogre_1_1_light.html#a04c17999a4050f4c9aebc1df19a4ff66", null ],
    [ "tempSquareDist", "class_ogre_1_1_light.html#ae3e2e4e50055bf99fd923ffa4f539f7d", null ]
];